@@ -16,7 +16,7 @@ class AnsiStyle(Enum):
     STRIKE = 9
 
 
-class AnsiForeColor(Enum):
+class AnsiFGColor(Enum):
     BLACK = 30
     RED = 31
     GREEN = 32
@@ -25,14 +25,14 @@ class AnsiForeColor(Enum):
     MAGENTA = 35
     CYAN = 36
     WHITE = 37
-    LIGHT_BLACK = 90
-    LIGHT_RED = 91
-    LIGHT_GREEN = 92
-    LIGHT_YELLOW = 93
-    LIGHT_BLUE = 94
-    LIGHT_MAGENTA = 95
-    LIGHT_CYAN = 96
-    LIGHT_WHITE = 97
+    LIGHTBLACK = 90
+    LIGHTRED = 91
+    LIGHTGREEN = 92
+    LIGHTYELLOW = 93
+    LIGHTBLUE = 94
+    LIGHTMAGENTA = 95
+    LIGHTCYAN = 96
+    LIGHTWHITE = 97
     LBLACK = 90
     LRED = 91
     LGREEN = 92
@@ -43,7 +43,7 @@ class AnsiForeColor(Enum):
     LWHITE = 97
 
 
-class AnsiBackColor(Enum):
+class AnsiBGColor(Enum):
     BLACK = 40
     RED = 41
     GREEN = 42
@@ -52,14 +52,14 @@ class AnsiBackColor(Enum):
     MAGENTA = 45
     CYAN = 46
     WHITE = 47
-    LIGHT_BLACK = 100
-    LIGHT_RED = 101
-    LIGHT_GREEN = 102
-    LIGHT_YELLOW = 103
-    LIGHT_BLUE = 104
-    LIGHT_MAGENTA = 105
-    LIGHT_CYAN = 106
-    LIGHT_WHITE = 107
+    LIGHTBLACK = 100
+    LIGHTRED = 101
+    LIGHTGREEN = 102
+    LIGHTYELLOW = 103
+    LIGHTBLUE = 104
+    LIGHTMAGENTA = 105
+    LIGHTCYAN = 106
+    LIGHTWHITE = 107
     LBLACK = 100
     LRED = 101
     LGREEN = 102
