@@ -1,11 +1,16 @@
 import re
+from collections import namedtuple
+from collections.abc import Sequence
+from colorsys import rgb_to_hsv
 from enum import Enum
-from typing import List, Optional, Sequence, Tuple, Type, Union, cast  # noqa
+from typing import Any, Optional, Union
 
 from ._const import CSI, RESET, AnsiBGColor, AnsiFGColor, AnsiStyle
 
 
-RGBTuple = Tuple[int, int, int]
+RGBTuple = tuple[int, int, int]
+
+HSV = namedtuple("HSV", "hue saturation value")
 
 _regexp_color_code = re.compile(
     "^#?(?P<red>[0-9a-f]{2})(?P<green>[0-9a-f]{2})(?P<blue>[0-9a-f]{2})$", re.IGNORECASE
@@ -39,6 +44,7 @@ class Color:
     def __init__(self, color: Union["Color", str, RGBTuple]) -> None:
         self.__name = ""
         self.__is_color_code_src = False
+        self.__hsv: Optional[HSV] = None
 
         if color is None:
             raise TypeError("color must be one of Color/str/RGBTuple")
@@ -55,15 +61,18 @@ class Color:
         try:
             # from a RGBTuple instance
             self.red, self.green, self.blue = color  # type: ignore
-            self.__validate_color_value(self.red)
-            self.__validate_color_value(self.green)
-            self.__validate_color_value(self.blue)
+            self.__validate_rgb_value(self.red)
+            self.__validate_rgb_value(self.green)
+            self.__validate_rgb_value(self.blue)
         except TypeError:
             # from a Color instance
             self.__name = color.name  # type: ignore
             self.red, self.green, self.blue = color.red, color.green, color.blue  # type: ignore
 
-    def __eq__(self, other) -> bool:
+    def __eq__(self, other: Any) -> bool:
+        if not isinstance(other, Color):
+            return False
+
         if self.name and other.name:
             return self.name == other.name
         elif self.name or other.name:
@@ -74,23 +83,24 @@ class Color:
 
         return False
 
-    def __ne__(self, other) -> bool:
+    def __ne__(self, other: Any) -> bool:
+        if not isinstance(other, Color):
+            return True
+
         return not self.__eq__(other)
 
     def __repr__(self) -> str:
-        items = [
-            "code={}, rgb=({}, {}, {})".format(self.color_code, self.red, self.green, self.blue)
-        ]
+        items = [f"code={self.color_code}, rgb=({self.red}, {self.green}, {self.blue})"]
 
         if self.__name:
-            items.append("name={}".format(self.__name))
+            items.append(f"name={self.__name}")
 
         return "Color({})".format(", ".join(items))
 
     def __from_color_code(self, color_code: str) -> None:
         match = _regexp_color_code.search(color_code)
         if match is None:
-            raise ValueError("invalid color code found: {}".format(color_code))
+            raise ValueError(f"invalid color code found: {color_code}")
 
         self.__is_color_code_src = True
         red, green, blue = match.group(1, 2, 3)
@@ -102,7 +112,7 @@ class Color:
         self.red, self.green, self.blue = name_to_rgb[name]
         self.__name = name
 
-    def __validate_color_value(self, n: int) -> None:
+    def __validate_rgb_value(self, n: int) -> None:
         if not (0 <= n <= 255):
             raise ValueError("value must be within 0-255")
 
@@ -116,25 +126,32 @@ class Color:
 
     @property
     def color_code(self) -> str:
-        return "#{:02x}{:02x}{:02x}".format(self.red, self.green, self.blue)
+        return f"#{self.red:02x}{self.green:02x}{self.blue:02x}"
+
+    @property
+    def hsv(self) -> HSV:
+        if self.__hsv is None:
+            self.__hsv = HSV(*rgb_to_hsv(self.red / 255, self.green / 255, self.blue / 255))
+
+        return self.__hsv
 
     def calc_scaler(self) -> int:
         return self.red + self.green + self.blue
 
-    def calc_complementary(self):
+    def calc_complementary(self) -> "Color":
         rgb = (self.red, self.green, self.blue)
         n = max(rgb) + min(rgb)
         return Color((n - self.red, n - self.green, n - self.blue))
 
 
-def _normalize_enum(value, enum_class: Type[Enum]):
+def _normalize_enum(value: Any, enum_class: type[Enum]) -> Any:
     if isinstance(value, enum_class):
         return value
 
     try:
         return enum_class[_normalize_name(value)]
     except AttributeError:
-        raise TypeError("value must be a {} or a str: actual={}".format(enum_class, type(value)))
+        raise TypeError(f"value must be a {enum_class} or a str: actual={type(value)}")
     except KeyError:
         raise ValueError(
             "invalid value found: expected={}, actual={}".format(
@@ -144,27 +161,27 @@ def _normalize_enum(value, enum_class: Type[Enum]):
 
 
 def _ansi_escape(value: str) -> str:
-    return "{}{}m".format(CSI, value)
+    return f"{CSI}{value}m"
 
 
 def _to_ansi_style(style: Union[str, AnsiStyle]) -> str:
-    return _ansi_escape("{}".format(_normalize_enum(style, AnsiStyle).value))
+    return _ansi_escape(f"{_normalize_enum(style, AnsiStyle).value}")
 
 
 def _to_ansi_fg_truecolor(color: Color) -> str:
-    return _ansi_escape("38;2;{};{};{}".format(color.red, color.green, color.blue))
+    return _ansi_escape(f"38;2;{color.red};{color.green};{color.blue}")
 
 
 def _to_ansi_bg_truecolor(color: Color) -> str:
-    return _ansi_escape("48;2;{};{};{}".format(color.red, color.green, color.blue))
+    return _ansi_escape(f"48;2;{color.red};{color.green};{color.blue}")
 
 
 def _to_ansi_fg_color(color: AnsiFGColor) -> str:
-    return _ansi_escape("{}".format(color.value))
+    return _ansi_escape(f"{color.value}")
 
 
 def _to_ansi_bg_color(color: AnsiBGColor) -> str:
-    return _ansi_escape("{}".format(color.value))
+    return _ansi_escape(f"{color.value}")
 
 
 def _make_ansi_fg_truecolor(color: Union[Color, str, RGBTuple, AnsiFGColor, None]) -> str:
@@ -222,7 +239,7 @@ def tcolor(
     ansi_fg_color = _make_ansi_fg_truecolor(color)
     ansi_bg_color = _make_ansi_bg_truecolor(bg_color)
 
-    ansi_styles = []  # type: List[str]
+    ansi_styles: list[str] = []
     if styles:
         ansi_styles = [_to_ansi_style(style) for style in styles]
 
